@@ -6,12 +6,10 @@
 int main (int argc, char **argv)
 {
     GMainLoop *loop;
-    CupsNotifier *notifier;
+    CupsNotifier *notifier = NULL;
     GDBusConnection *con;
     GError *error = NULL;
 
-    g_type_init ();
-
     loop = g_main_loop_new (NULL, FALSE);
 
     con = g_bus_get_sync (G_BUS_TYPE_SYSTEM, NULL, &error);
